[HTML5 Boilerplate homepage](http://html5boilerplate.com)

# HTML5 Boilerplate documentation:

## Getting started

* [Usage](usage.md) — Overview of the project contents.
* [FAQ](faq.md) — Frequently asked questions, along with their answers.

## The core of HTML5 Boilerplate

* [HTML](html.md) — A guide to the default HTML.
* [CSS](css.md) — A guide to the default CSS.
* [JavaScript](js.md) — A guide to the default JavaScript.
* [.htaccess](htaccess.md) — All about the Apache web server config (also see
  our [alternative server configs](https://github.com/h5bp/server-configs)).
* [crossdomain.xml](crossdomain.md) — An introduction to making use of
  crossdomain requests.
* [Everything else](misc.md).

## Development

* [Extending and customizing HTML5 Boilerplate](extend.md) — Going further with
  the boilerplate.

## Related projects

HTML5 Boilerplate has several related projects to help improve the performance
of your site/app in various production environments.

* [Server configs](https://github.com/h5bp/server-configs) — Configs for
  non-Apache servers.
* [Node build script](https://github.com/h5bp/node-build-script) — A
  feature-rich [grunt](https://github.com/cowboy/grunt) plugin.
* [Ant build script](https://github.com/h5bp/ant-build-script) — The original
  HTML5 Boilerplate build script.
